ML Insights
===========

Package to understand ML Models


Disclaimer
==========

We have tested this tool to the best of my ability, but understand that it may have bugs. Use at your own risk!


Installation
=============

.. code-block:: bash

    $ pip install ml_insights


Usage
======

.. code-block:: python

    >>> import ml_insights as mli
    >>> xray = mli.ModelXRay(model, data)


Source
======

Find the latest version on github: https://github.com/numeristical/introspective

Feel free to fork and contribute!

Documentation
==============

- `API Docs <https://ml-insights.readthedocs.io>`_
- `Notebook Examples and Usage <examples/>`_

Requirements
============

Python
------
Python 2.7 and 3.4+


License
=======

Free software: `MIT license <LICENSE>`_

Developed By
============

- Brian Lucena
- Ramesh Sampath

References
==========

Alex Goldstein, Adam Kapelner, Justin Bleich, and Emil Pitkin. 2014. Peeking Inside the Black Box: Visualizing Statistical Learning With Plots of Individual Conditional Expectation. Journal of Computational and Graphical Statistics (March 2014)
